testfun: Functions for Testing Purposes

testfunR Documentation

Functions for Testing Purposes

Description

Functions that can be used in simulations to test the effectiveness of the sharpening procedures.

Usage

 testfun(x, k) 

Arguments

x

numeric vector

k

a numeric constant that controls the height of the peak of the test function; if missing, a periodic function is supplied

Value

numeric vector of function output

Author(s)

D.Wang


sharpPen documentation built on April 3, 2025, 7:10 p.m.

Related to testfun in sharpPen...