| testfun | R Documentation |
Functions that can be used in simulations to test the effectiveness of the sharpening procedures.
testfun(x, k)
x |
numeric vector |
k |
a numeric constant that controls the height of the peak of the test function; if missing, a periodic function is supplied |
numeric vector of function output
D.Wang
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.